@@ -36,6 +36,7 @@
 #include <config.h>
 #include "gnome-macros.h"
 
+#include <sys/param.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -54,6 +55,15 @@
 #include "gnome-i18n.h"
 #include "gnome-url.h"
 
+#include "libgnome-private.h"
+
+#ifdef G_OS_WIN32
+#define getuid() 42
+#define geteuid() getuid()
+#define getgid() 42
+#define getegid() getgid()
+#endif
+
 struct _GnomeProgramPrivate {
     enum {
 	APP_UNINIT=0,
@@ -1928,6 +1938,11 @@ gnome_program_init_paramv (GType type,
                            int argc, char **argv,
                            guint nparams, GParameter *params)
 {
+    va_list args;
+
+    g_return_val_if_fail (nparams >= 0, NULL);
+
     return gnome_program_init_common (type, app_id, app_version, module_info,
-				      argc, argv, NULL, 0, nparams, params);
+				      argc, argv, NULL, args, nparams, params);
+
 }
